@@ -8,7 +8,7 @@ from uuid import uuid4, UUID
 
 from preseem import FakeNetworkMetadataModel, NetworkMetadataReference, FakePreseemModel
 from preseem.model_sync import sync_preseem_model, ElementSyncItem
-from preseem_protobuf.model.element_pb2 import ElementStatus
+from preseem_protobuf.model.common_pb2 import ElementStatus
 from preseem_protobuf.model.account_pb2 import AccountStatus
 from preseem_protobuf.model.common_pb2 import AccountType
 from preseem.source_model import Attachment, Olt, Router, Service
