@@ -1378,6 +1378,12 @@ class TestNetworkElementUpdate(unittest.TestCase):
         self.assertEqual(len(pon.errctx.errors), 2)
         pon.errctx = None
 
+        self.assertEqual(pon.name, None)
+        pon.name = 'pon-name'
+        self.assertEqual(pon.name, 'pon-name')
+        pon.name = None
+        self.assertEqual(pon.name, None)
+
         # PonLink
         ponlink = pon.links.add()
         poller_hash = sha256().digest()
